package com.ruoyi.mall.service;

import java.util.List;

import com.ruoyi.common.utils.ApiResult;
import com.ruoyi.mall.domain.MallMemberCms;

/**
 * 手机验证码Service接口
 *
 * @author ruoyi
 * @date 2022-06-28
 */
public interface IMallMemberCmsService
{
    /**
     * 比对验证码，有效期10分钟
     * @param phone 手机号
     * @param cmsCode 验证码
     * @return
     */
    public int checkCmsCode(String phone,String cmsCode);
    /**
     * 查询手机验证码
     *
     * @param id 手机验证码主键
     * @return 手机验证码
     */
    public MallMemberCms selectMallMemberCmsById(Long id);

    /**
     * 查询手机验证码列表
     *
     * @param mallMemberCms 手机验证码
     * @return 手机验证码集合
     */
    public List<MallMemberCms> selectMallMemberCmsList(MallMemberCms mallMemberCms);

    /**
     * 新增手机验证码
     *
     * @param mallMemberCms 手机验证码
     * @return 结果
     */
    public int insertMallMemberCms(MallMemberCms mallMemberCms);

    /**
     * 发送手机验证码
     *
     * @param mallMemberCms 手机验证码
     * @return 结果
     */
    public ApiResult sendCmsCode(MallMemberCms mallMemberCms);

    /**
     * 修改手机验证码
     *
     * @param mallMemberCms 手机验证码
     * @return 结果
     */
    public int updateMallMemberCms(MallMemberCms mallMemberCms);

    /**
     * 批量删除手机验证码
     *
     * @param ids 需要删除的手机验证码主键集合
     * @return 结果
     */
    public int deleteMallMemberCmsByIds(Long[] ids);

    /**
     * 删除手机验证码信息
     *
     * @param id 手机验证码主键
     * @return 结果
     */
    public int deleteMallMemberCmsById(Long id);
}
